@@ -10,9 +10,9 @@
 ;;; Please refer to the file ACKNOWLEGDEMENTS for an (incomplete) list
 ;;; of present and past contributors.
 ;;;
-;;; $Id: lucid.lisp,v 1.3 2001/07/02 09:40:49 youngs Exp $
+;;; $Id: lucid.lisp,v 1.4 2002/05/30 13:59:21 wbd Exp $
 
-(in-package "ILISP")
+(in-package :ilisp)
 
 ;;;
 (defun ilisp-callers (symbol package &aux (list-of-callers nil))
